@@ -25,6 +25,23 @@ import pyutilib.services
 from pyutilib.common import *
 from pyutilib.misc import quote_split
 
+try:
+    unicode
+except:
+    basestring = unicode = str
+
+if sys.version_info[0:2] >= (3,0):
+    def bytes_cast(x):
+        if not x is None:
+            if isinstance(x,basestring) is True:
+                return x.encode() # Encode string to bytes type
+            else:
+                # lets assume its of type bytes
+                return x
+        else:
+            return x
+else:
+    bytes_cast = lambda x:x # Do nothing
 
 
 def kill_process(process, sig=signal.SIGTERM, verbose=False):
@@ -287,6 +304,7 @@ def run_command(cmd, outfile=None, cwd=None, ostream=None, stdin=None, stdout=No
     elif not tmpfile is None and not ignore_output:
         tmpfile.seek(0)
         output = "".join(tmpfile.readlines())
+        tmpfile.close()
     sys.stdout.flush()
     sys.stderr.flush()
     #
@@ -385,7 +403,8 @@ class SubprocessMngr(object):
         timelimit has passed.
         """
         if timelimit is None:
-            self.process.communicate(input=self.stdin)
+            # *Py3k: bytes_cast does no conversion for python 2.*, casts to bytes for 3.*
+            self.process.communicate(input=bytes_cast(self.stdin))
             return self.process.returncode
         else:
             #
@@ -400,7 +419,8 @@ class SubprocessMngr(object):
             # This might be dangerous: we *could* deadlock if the input
             # is large...
             if self.stdin is not None:
-                self.process.stdin.write(self.stdin)
+                # *Py3k: bytes_cast does no conversion for python 2.*, casts to bytes for 3.*
+                self.process.stdin.write(bytes_cast(self.stdin))
             
             while timer() < endtime:
                 status = self.process.poll()
