@@ -8,6 +8,12 @@ from nose.tools import nottest
 import pyutilib.services
 from pyutilib.subprocess import subprocess, SubprocessMngr, timer
 
+try:
+    import __pypy__
+    is_pypy = True
+except:
+    is_pypy = False
+
 pyutilib.services.register_executable("memmon")
 pyutilib.services.register_executable("valgrind")
 
@@ -25,6 +31,8 @@ class Test(unittest.TestCase):
             foo.wait()
             print("")
 
+    @unittest.skipIf(is_pypy, "Cannot launch python in this test with pypy")
+    def test_bar(self):
         stime = timer()
         # On MS Windows, do not run this in a shell.  If so, MS Windows has difficulty
         # killing the process after the timelimit
